@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+#
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
 #    a copy of the License at
@@ -45,10 +47,10 @@ def _get_endpoint(client, **kwargs):
 
 
 def get_client(api_version, **kwargs):
-    """Get an authtenticated client, based on the credentials
+    """Get an authenticated client, based on the credentials
        in the keyword args.
 
-    :param api_version: the API version to use ('1' or '2')
+    :param api_version: the API version to use. Valid value: '1'.
     :param kwargs: keyword args containing credentials, either:
             * os_auth_token: pre-existing token to re-use
             * ironic_url: ironic API endpoint
@@ -63,6 +65,7 @@ def get_client(api_version, **kwargs):
     if kwargs.get('os_auth_token') and kwargs.get('ironic_url'):
         token = kwargs.get('os_auth_token')
         endpoint = kwargs.get('ironic_url')
+        auth_ref = None
     elif (kwargs.get('os_username') and
           kwargs.get('os_password') and
           kwargs.get('os_auth_url') and
@@ -85,6 +88,9 @@ def get_client(api_version, **kwargs):
 
         endpoint = kwargs.get('ironic_url') or \
             _get_endpoint(_ksclient, **ks_kwargs)
+
+        auth_ref = _ksclient.auth_ref
+
     else:
         e = (_('Must provide Keystone credentials or user-defined endpoint '
                'and token'))
@@ -97,6 +103,7 @@ def get_client(api_version, **kwargs):
         'ca_file': kwargs.get('ca_file'),
         'cert_file': kwargs.get('cert_file'),
         'key_file': kwargs.get('key_file'),
+        'auth_ref': auth_ref,
     }
 
     return Client(api_version, endpoint, **cli_kwargs)
