@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+#
 # Copyright 2012 OpenStack LLC.
 # All Rights Reserved.
 #
@@ -21,9 +23,9 @@ import socket
 import ssl
 
 import six
+import six.moves.urllib.parse as urlparse
 
 from ironicclient import exc
-from ironicclient.openstack.common.py3kcompat import urlutils
 
 
 LOG = logging.getLogger(__name__)
@@ -36,11 +38,12 @@ class HTTPClient(object):
     def __init__(self, endpoint, **kwargs):
         self.endpoint = endpoint
         self.auth_token = kwargs.get('token')
+        self.auth_ref = kwargs.get('auth_ref')
         self.connection_params = self.get_connection_params(endpoint, **kwargs)
 
     @staticmethod
     def get_connection_params(endpoint, **kwargs):
-        parts = urlutils.urlparse(endpoint)
+        parts = urlparse.urlparse(endpoint)
 
         _args = (parts.hostname, parts.port, parts.path)
         _kwargs = {'timeout': (float(kwargs.get('timeout'))
@@ -56,7 +59,7 @@ class HTTPClient(object):
             _class = six.moves.http_client.HTTPConnection
         else:
             msg = 'Unsupported scheme: %s' % parts.scheme
-            raise exc.InvalidEndpoint(msg)
+            raise exc.EndpointException(msg)
 
         return (_class, _args, _kwargs)
 
@@ -66,7 +69,7 @@ class HTTPClient(object):
             return _class(*self.connection_params[1][0:2],
                           **self.connection_params[2])
         except six.moves.http_client.InvalidURL:
-            raise exc.InvalidEndpoint()
+            raise exc.EndpointException()
 
     def log_curl_request(self, method, url, kwargs):
         curl = ['curl -i -X %s' % method]
@@ -143,12 +146,12 @@ class HTTPClient(object):
         except socket.gaierror as e:
             message = ("Error finding address for %(url)s: %(e)s"
                        % dict(url=url, e=e))
-            raise exc.InvalidEndpoint(message=message)
+            raise exc.EndpointNotFound(message)
         except (socket.error, socket.timeout) as e:
             endpoint = self.endpoint
             message = ("Error communicating with %(endpoint)s %(e)s"
                        % dict(endpoint=endpoint, e=e))
-            raise exc.CommunicationError(message=message)
+            raise exc.ConnectionRefused(message)
 
         body_iter = ResponseBodyIterator(resp)
 
@@ -164,14 +167,14 @@ class HTTPClient(object):
         if 400 <= resp.status < 600:
             LOG.warn("Request returned failure status.")
             error_json = self._extract_error_json(body_str)
-            raise exc.from_response(resp,
-                                    error_json.get('faultstring'),
-                                    error_json.get('debuginfo'))
+            raise exc.from_response(
+                resp, error_json.get('faultstring'),
+                error_json.get('debuginfo'), method, url)
         elif resp.status in (301, 302, 305):
             # Redirected. Reissue the request to the new location.
             return self._http_request(resp['location'], method, **kwargs)
         elif resp.status == 300:
-            raise exc.from_response(resp)
+            raise exc.from_response(resp, method=method, url=url)
 
         return resp, body_iter
 
